@@ -18,9 +18,11 @@ logger.basic_config(handlers=[FileSystemHandler], level="INFO")
 logger.set_stream("./", FileSystemHandler)
 
 
-def get_telegram_logger(filename: str):
+def get_telegram_logger(filename: str, ini_file_path: str):
     _tlogger = sherlog.get_logger(filename)
-    _tlogger.basic_config(handlers=[TelegramHandler], level="INFO")
+    _tlogger.basic_config(
+        handlers=[TelegramHandler], level="INFO", plugins_ini_path=ini_file_path
+    )
     return _tlogger
 
 
